==> UnderB-1.01.tar.gz: UnderB-1.01/tools/pseudo.c <==
#include <signal.h>
#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <curses.h>

#ifdef linux
#define	sig_t	void
#else
# ifdef sun
# define sig_t	int
# endif
#endif

#define	FINGER	"/usr/bin/finger"
#define	TARGET	"h-lee5@uxa.cso.uiuc.edu"
#define	BUFSIZE	256
#define	PATTERN		"slip"

int in_curse = 0;

sig_t
die ()
{
  if (in_curse)
    {
      endwin();
    }
  printf ("\n\nHey! You're not supposed to do this!! Get out!\n");
  exit (0);
}

main ()
{
  FILE *in;
  static char host[BUFSIZE + 1];
  static char cmd[BUFSIZE + 1];
  static char line[BUFSIZE + 1];
  static char result[BUFSIZE + 1];
  register char *ptr1, *ptr2;

  signal (SIGHUP, (sig_t (*)())die);
  signal (SIGINT, (sig_t (*)())die);
  signal (SIGQUIT, (sig_t (*)())die);
  signal (SIGILL, (sig_t (*)())die);
  signal (SIGTERM, (sig_t (*)())die);
  signal (SIGSTOP, (sig_t (*)())die);
#ifdef SIGTSTP
  signal (SIGTSTP, (sig_t (*)())die);
#endif
  signal (SIGCONT, (sig_t (*)())die);

  sprintf (cmd, "%s %s", FINGER, TARGET);

  initscr();
  in_curse = 1;
  clear();
  mvaddstr(5,20, "Getting info. from UIUC.....");
  refresh();

  if ((in = popen (cmd, "r")) == NULL)
    {
      perror ("popen");
      exit (1);
    }
  while (fgets (line, BUFSIZE, in))
    {
      if ((ptr1 = strstr (line, PATTERN)) == (char *) NULL)
	continue;
      ptr2 = (char*)result;
      while (*ptr1 && *ptr1 != ' ')
	ptr1--;
      ptr1++;
      while (*ptr1 && *ptr1 != '.')
	{
	  *ptr2++ = *ptr1++;
	}
      *ptr2 = '\0';
      strcat (result, ".slip.uiuc.edu");
      break;
    }
  pclose (in);

  mvaddstr(7, 20, "The PseudoBBS is at");
  mvaddch(9, 20, '[');
  standout();
  mvaddstr(9, 21, result);
  standend();
  mvaddch(9, 21+strlen(result), ']');
  refresh();

  cbreak();
  mvaddstr(23, 0, "Press Any key to continue..");
  refresh();
  getch();
  nocbreak();

  endwin();
  return 0;
}

==> UnderB-1.091.tar.gz: UnderB-1.091/tools/pseudo.c <==
#include <signal.h>
#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <curses.h>

#ifdef linux
#define	sig_t	void
#else
# ifdef sun
# define sig_t	int
# endif
#endif

/*
	This is when it's using fixed address..
*/
#define	NEWPSEUDO	"sparc8.cse.uiuc.edu"
#define	FINGER	"/usr/bin/finger"
#define	OPTS	"-m"
#define	TARGET	"h-lee5@ux4.cso.uiuc.edu"
#define	BUFSIZE	256
#define	PATTERN		"slip"

int in_curse = 0;

sig_t
die ()
{
  if (in_curse)
    {
      endwin();
    }
  printf ("\n\nHey! You're not supposed to do this!! Get out!\n");
  exit (0);
}

main ()
{
#ifdef DELETED
  FILE *in;
  static char host[BUFSIZE + 1];
  static char cmd[BUFSIZE + 1];
  static char line[BUFSIZE + 1];
#endif
  static char result[BUFSIZE + 1];
#ifdef DELETED
  register char *ptr1, *ptr2;
#endif

  signal (SIGHUP, (sig_t (*)())die);
  signal (SIGINT, (sig_t (*)())die);
  signal (SIGQUIT, (sig_t (*)())die);
  signal (SIGILL, (sig_t (*)())die);
  signal (SIGTERM, (sig_t (*)())die);
  signal (SIGSTOP, (sig_t (*)())die);
#ifdef SIGTSTP
  signal (SIGTSTP, (sig_t (*)())die);
#endif
  signal (SIGCONT, (sig_t (*)())die);

#ifdef DELETED
  sprintf (cmd, "%s %s %s", FINGER, OPTS, TARGET);
#endif

  initscr();
  in_curse = 1;
  clear();
#ifdef DELETED
  mvaddstr(5,20, "Getting info. from UIUC.....");
  refresh();

  if ((in = popen (cmd, "r")) == NULL)
    {
      perror ("popen");
      exit (1);
    }
  while (fgets (line, BUFSIZE, in))
    {
      if ((ptr1 = strstr (line, PATTERN)) == (char *) NULL)
	continue;
      ptr2 = (char*)result;
      while (*ptr1 && *ptr1 != ' ')
	ptr1--;
      ptr1++;
      while (*ptr1 && *ptr1 != '.')
	{
	  *ptr2++ = *ptr1++;
	}
      *ptr2 = '\0';
      strcat (result, ".slip.uiuc.edu");
      break;
    }
  pclose (in);
#else
  strcpy(result, NEWPSEUDO);
#endif

  mvaddstr(7, 20, "The PseudoBBS is at");
  mvaddch(9, 20, '[');
  standout();
  mvaddstr(9, 21, result);
  standend();
  mvaddch(9, 21+strlen(result), ']');
  refresh();
  cbreak();
  mvaddstr(23, 0, "Press Any key to continue..");
  refresh();
  getch();
  nocbreak();

  endwin();
  return 0;
}
